@@ -74,7 +74,23 @@ class Storage(driver.Base):
         finally:
             output.close()
 
-    
+    def stream_read(self, path, bytes_range=None):
+        logger.info("stream_read path:%s" % path)
+        path1 = self._init_path(path)
+        
+        try:
+            object_instance = self._jss.bucket(self._bucket).object(path1)
+            res = object_instance.download_flow()
+            while True:
+                data = res.read(1024)
+                if len(data) != 0:
+                    yield data
+                else:
+                    break
+        except Exception as e:
+            logger.error("stream_read error:%s" % e)
+            raise exceptions.FileNotFoundError("File not found %s" % path)
+        
     @lru.set
     def put_content(self, path, content):
         logger.info("put_content path:%s" % path)
@@ -124,7 +140,6 @@ class Storage(driver.Base):
             logger.error("list_directory error:%s" % e)
             raise exceptions.FileNotFoundError("File not found %s" % path)
         
-        
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
         path1 = self._init_path(path)
